@@ -50,9 +50,11 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 use Carp;
+use Time::Local;
 use Net::Gopher::Utility qw($CRLF $NEWLINE);
 
-$VERSION = '0.20';
+$VERSION = '0.21';
+
 
 
 
@@ -138,7 +140,7 @@ sub status
 
 For a Gopher+ request, if the request was successful, this method will return
 the content of the response (everything after the status line). For a Gopher
-request, this just returns the same thing as the L<as_string()> method does.
+request, this just returns the same thing as the as_string() method does.
 
 =cut
 
@@ -190,10 +192,10 @@ following keys:
  selector = The selector string (e.g., /foo/bar);
  host     = The hostname (e.g., gopher.host.com);
  port     = The port number (e.g., 70);
- gopher+  = The Gopher+ string if this item is on a Gopher+ server);
+ gopher+  = The Gopher+ string if this item is on a Gopher+ server;
 
 The array will only contain hashrefs of items that list some type of resource
-that can be downloaded; meaning that inline text is skipped ('i' item type).
+that can be downloaded; meaning that inline text ('i' item type) is skipped.
 
 =cut
 
@@ -207,6 +209,9 @@ sub as_menu
 	my @menu;
 	foreach my $item (@items)
 	{
+		# skip it if it's not a menu item:
+		next unless ($item =~ /\t/);
+
 		# create a hashref of this item:
 		my $item_hash = $self->_get_item_hashref($item);
 
@@ -232,40 +237,66 @@ sub as_menu
 
 #==============================================================================#
 
-=item as_info()
+=item as_blocks()
 
-If the request was a Gopher+ attribute information request, then you can use
-method to parse the attribute information in the server's response. This
+If the request was a Gopher+ attribute information request then you can use
+method to parse the attribute information blocks in the server's response. This
 method will return a hash (in list context) or a reference to a hash (in scalar
 context) with information block names as its keys and block values as its
 values. Please note that this method strips trailing colons from block names
 (e.g., ADMIN: becomes ADMIN). Also, it should be pointed out that since the
 structure of block values often differ from server to server, this method won't
-attempt to parse them; that is, except for INFO, ADMIN, and VIEWS blocks
-which each Gopher+ server is mandated to return (and the same format) by the
-Gopher+ protocol Since INFO blocks contain tab separated item information just
-like you'd find in a menu, the hash  value for 'INFO' will contain a reference
-to another hash, one in the format described above (L<as_menu()>):
+attempt to parse any blocks except for INFO, ADMIN, and VIEWS blocks, which
+each Gopher+ server is mandated to return (and in the same format) by the
+Gopher+ protocol. Since INFO blocks contain tab separated item information just
+like you'd find in a menu, the value for 'INFO' will be a reference to another
+hash, one in the format described above (L<as_menu()>):
 
- print "Type: $blocks{'INFO'}->{'type'}\n",
-       "Description: $blocks{'INFO'}->{'text'}\n",
-       "On $blocks{'INFO'}->{'host'}\n",
-       "At $blocks{'INFO'}->{'port'}\n";
+ my %blocks = $response->as_blocks;
+ 
+ print "Type: $blocks{'INFO'}{'type'}\n",
+       "Description: $blocks{'INFO'}{'text'}\n",
+       "On $blocks{'INFO'}{'host'}\n",
+       "At $blocks{'INFO'}{'port'}\n";
 
-VIEWS blocks contain information
+VIEWS blocks contain information about what type of applications can be used
+to view the item as well as the total size of the item in bytes
+(e.g., Text/plain: <77K>). This method will turn a VIEWS block into a hashref
+where the MIME type is the key and the value is the size in bytes. Note, this
+method converts the <\d+K?> format used in Gopher+ to an integer you can
+preform arathmatic on (e.g., <80> becomes 80, <40K> becomes 40000, etc.):
+
+print "Size: ", $blocks{'VIEWS'}{'Text/plain'};
+
+ADMIN blocks contain information about the person running the Gopher+ server
+and what the admin has done with the item in question. This method will
+parse ADMIN blocks and create a hashref with two key=value pairs: Admin and
+Mod-Date. Admin contains a string in the form of "John Doe <jdoe@fake.email>"
+about who the adminstrator of this Gopher+ server is. Mod-Date is a timestamp
+of when the item was last modified, usually like the ones returned by C's
+ctime(). This method will convert the timestamp into an array contaiing values
+returned by Perl's localtime() function corresponding with the Mod-Date (see
+L<perldoc -f localtime>):
+
+ print "This box is maintained by ", $blocks{'ADMIN'}{'admin'};
+ 
+ my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) =
+ @{ $blocks{'ADMIN'}{'Mod-Date'} };
 
 =cut
 
-sub as_info
+sub as_blocks
 {
 	my $self = shift;
 
 	# remove the leading +:
-	(my $blocks = $self->{'content'}) =~ s/[^+]* \+//x;
-	my @blocks = split(/\n\+/, $blocks);
+	(my $blocks = $self->{'content'}) =~ s/[^+]*? \+//x;
 
-	my %info;
-	foreach my $block (@blocks)
+	# get each block name and value:
+	my @block_name_and_values = split(/\n\+/, $blocks);
+
+	my %blocks;
+	foreach my $block (@block_name_and_values)
 	{
 		# get the block name and block value (separated by the first
 		# space):
@@ -289,7 +320,7 @@ sub as_info
 			$value = $self->_get_infoblock_hashref($value);
 
 			# A size in the form of <55K> is of little use to the
-			# user. Let's change that to something more useful:
+			# user. Let's change that to an integer:
 			foreach my $mime_type (keys %$value)
 			{
 				if ($value->{$mime_type} =~ /<(\d+)(k)?>/i)
@@ -309,21 +340,82 @@ sub as_info
 			# Admin: Foo Bar <foobar@foo.com>
 			# Mod-Date: Wed Jul 28 17:02:01 1993
 			# 
-			# So we need to get each of them in a hashref:
+			# first, get both of them in a hashref:
 			$value = $self->_get_infoblock_hashref($value);
+
+			# get the values from the Mod-Date timestamp: 
+			my ($day, $month, $month_day,
+			    $hour, $minute, $second, $year) = 
+					$value->{'Mod-Date'} =~
+						/(\w+)\s+(\w+)\s+(\d+)\s+
+						 (\d+):(\d+):(\d+)\s+(\d+)/x;
+
+			foreach ($day, $month, $month_day, $hour, $minute,
+				$second, $year)
+			{
+				croak "Couldn't parse timestamp"
+					unless (defined);
+			}
+
+			# if the server's date format contains a full
+			# month name then we need to shorten it to just the
+			# first three letters so we can easily convert it to
+			# its respective localtime() number:
+			$month =~ s/^(\w{3})\w+/$1/;
+
+			# it's easier to convert it if it's in all lowercase:
+			$month = lc $month;
+	
+			# now, replace the month name with a number like the
+			# one returned localtime():
+			$month = {
+				jan   => 0,
+				feb   => 1,
+				mar   => 2,
+				apr   => 3,
+				may   => 4,
+				jun   => 5,
+				jul   => 6,
+				aug   => 7,
+				sep   => 8,
+				'oct' => 9,
+				nov   => 10,
+				dec   => 11,
+			}->{$month};
+
+			# turn 2 diget years into 4 diget years:
+			$year = 20 . $year if (length $year < 4);
+
+			# convert the year to the number of years since 1900
+			# (e.g., 2003 -> 103) since that's the format returned
+			# by localtime():
+			$year -= 1900;
+
+			# now that we have the second, minute, hour, day,
+			# month, and year, we use them to get a corresponding
+			# Perl time() value:
+			my $time = timelocal(
+				$second, $minute, $hour,
+				$month_day, $month, $year
+			);
+
+			# now use the time() value to get the values we still
+			# don't have (e.g., the day of the year, is it daylight
+			# savings time? Etc.) and store them in the Mod-Date
+			# attribute value:
+			$value->{'Mod-Date'} = [ localtime $time ];
 		}
 
-		# now save the block:
-		$info{$name} = $value;
+		$blocks{$name} = $value;
 	}
 
 	if (wantarray)
 	{
-		return %info;
+		return %blocks;
 	}
 	else
 	{
-		return \%info;
+		return \%blocks;
 	}
 }
 
@@ -336,13 +428,20 @@ sub _get_item_hashref
 	my $self = shift;
 	my $item = shift;
 
-	# get the item type and description text, selector, host, port:
+	# get the item type and description text, selector, host, port, and
+	# Gopher+ string:
 	my ($type_and_text, $selector, $host, $port, $gopher_plus) =
 		split(/\t/, $item);
 
 	# now we need to separate the type and the text:
 	my ($type, $text) = $type_and_text =~ /^(.)(.*)/;
 
+	foreach ($type, $text, $selector, $host, $port)
+	{
+		croak "Couldn't parse menu item" unless (defined $_);
+	}
+
+	# create a hashref for this item:
 	my $item_hash = {
 		type      => $type,
 		text      => $text,
@@ -363,7 +462,7 @@ sub _get_infoblock_hashref
 	my $self        = shift;
 	my $block_value = shift;
 
-	# first, get rid of all leading whitespace:
+	# strip leading white space from the value:
 	$block_value =~ s/^\s*//;
 
 	# now seaparate each attribute:
@@ -372,8 +471,11 @@ sub _get_infoblock_hashref
 	my %block_attributes;
 	foreach my $attribute (@attributes)
 	{
+		# first, get rid of all leading whitespace:
+		$attribute =~ s/^\s*//;
+
 		# get the "Name: value" attribute:
-		my ($name, $value) = $attribute =~ /^(\S+):\s*(\S*)/;
+		my ($name, $value) = $attribute =~ /^(.+?):\s*(.*)/;
 
 		$block_attributes{$name} = $value;
 	}
@@ -398,8 +500,9 @@ Basically, since Gopher has no built-in uniform error-handling, as long as
 some response was received from the server (even "An error has occurred" or
 "The item you requested does not exist"), this will return true. For more
 accuracy with Gopher requests, you can use the is_terminated() method. If this
-method returns false, meaning an error has occurred, then you can find out why
-by calling the error() method on the Net::Gopher::Response object.
+method returns false, meaning an error has occurred, then you can obtain the
+error message by calling the error() method on the Net::Gopher::Response
+object.
 
 =cut
 
